
From: Stephen Rothwell <sfr@canb.auug.org.au>

This patch removes from the iSeries header files a large number of inline
functions that are not used.  It also changes the only caller of a HvCallCfg
function that is outside HvLpConfig.h to its equivalent HvLpConfig function
and no longer includes HvCallCfg.h where it is not needed.

Signed-off-by: Stephen Rothwell <sfr@canb.auug.org.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc64/kernel/iSeries_smp.c        |    1 
 arch/ppc64/kernel/viopath.c            |    3 
 include/asm-ppc64/iSeries/HvCallCfg.h  |   53 ---------
 include/asm-ppc64/iSeries/HvLpConfig.h |  188 ---------------------------------
 4 files changed, 3 insertions(+), 242 deletions(-)

diff -puN arch/ppc64/kernel/iSeries_smp.c~ppc64-iseries-eliminate-some-unused-inline-functions arch/ppc64/kernel/iSeries_smp.c
--- 25/arch/ppc64/kernel/iSeries_smp.c~ppc64-iseries-eliminate-some-unused-inline-functions	2005-06-03 02:15:59.000000000 -0700
+++ 25-akpm/arch/ppc64/kernel/iSeries_smp.c	2005-06-03 02:15:59.000000000 -0700
@@ -39,7 +39,6 @@
 #include <asm/smp.h>
 #include <asm/paca.h>
 #include <asm/iSeries/HvCall.h>
-#include <asm/iSeries/HvCallCfg.h>
 #include <asm/time.h>
 #include <asm/ppcdebug.h>
 #include <asm/machdep.h>
diff -puN arch/ppc64/kernel/viopath.c~ppc64-iseries-eliminate-some-unused-inline-functions arch/ppc64/kernel/viopath.c
--- 25/arch/ppc64/kernel/viopath.c~ppc64-iseries-eliminate-some-unused-inline-functions	2005-06-03 02:15:59.000000000 -0700
+++ 25-akpm/arch/ppc64/kernel/viopath.c	2005-06-03 02:15:59.000000000 -0700
@@ -46,7 +46,6 @@
 #include <asm/iSeries/ItExtVpdPanel.h>
 #include <asm/iSeries/HvLpEvent.h>
 #include <asm/iSeries/HvLpConfig.h>
-#include <asm/iSeries/HvCallCfg.h>
 #include <asm/iSeries/mf.h>
 #include <asm/iSeries/vio.h>
 
@@ -364,7 +363,7 @@ void vio_set_hostlp(void)
 	 * while we're active
 	 */
 	viopath_ourLp = HvLpConfig_getLpIndex();
-	viopath_hostLp = HvCallCfg_getHostingLpIndex(viopath_ourLp);
+	viopath_hostLp = HvLpConfig_getHostingLpIndex(viopath_ourLp);
 
 	if (viopath_hostLp != HvLpIndexInvalid)
 		vio_setHandler(viomajorsubtype_config, handleConfig);
diff -puN include/asm-ppc64/iSeries/HvCallCfg.h~ppc64-iseries-eliminate-some-unused-inline-functions include/asm-ppc64/iSeries/HvCallCfg.h
--- 25/include/asm-ppc64/iSeries/HvCallCfg.h~ppc64-iseries-eliminate-some-unused-inline-functions	2005-06-03 02:15:59.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/HvCallCfg.h	2005-06-03 02:15:59.000000000 -0700
@@ -67,31 +67,11 @@ enum HvCallCfg_ReqQual {
 #define HvCallCfgGetLpExecutionMode			HvCallCfg + 31
 #define HvCallCfgGetHostingLpIndex			HvCallCfg + 32
 
-static inline HvLpIndex	HvCallCfg_getLps(void)
-{
-	return HvCall0(HvCallCfgGetLps);
-}
-
-static inline int HvCallCfg_isBusDedicated(u64 busIndex)
-{
-	return HvCall1(HvCallCfgIsBusDedicated, busIndex);
-}
-
 static inline HvLpIndex	HvCallCfg_getBusOwner(u64 busIndex)
 {
 	return HvCall1(HvCallCfgGetBusOwner, busIndex);
 }
 
-static inline HvLpIndexMap HvCallCfg_getBusAllocation(u64 busIndex)
-{
-	return HvCall1(HvCallCfgGetBusAllocation, busIndex);
-}
-
-static inline HvLpIndexMap HvCallCfg_getActiveLpMap(void)
-{
-	return HvCall0(HvCallCfgGetActiveLpMap);
-}
-
 static inline HvLpVirtualLanIndexMap HvCallCfg_getVirtualLanIndexMap(
 		HvLpIndex lp)
 {
@@ -105,31 +85,12 @@ static inline HvLpVirtualLanIndexMap HvC
 	return retVal;
 }
 
-static inline u64 HvCallCfg_getSystemMsChunks(void)
-{
-	return HvCall0(HvCallCfgGetSystemMsChunks);
-}
-
 static inline u64 HvCallCfg_getMsChunks(HvLpIndex lp,
 		enum HvCallCfg_ReqQual qual)
 {
 	return HvCall2(HvCallCfgGetMsChunks, lp, qual);
 }
 
-static inline u64 HvCallCfg_getMinRuntimeMsChunks(HvLpIndex lp)
-{
-	/*
-	 * NOTE: This function was added in v5r1 so older hypervisors
-	 * will return a -1 value
-	 */
-	return HvCall1(HvCallCfgGetMinRuntimeMsChunks, lp);
-}
-
-static inline u64 HvCallCfg_setMinRuntimeMsChunks(u64 chunks)
-{
-	return HvCall1(HvCallCfgSetMinRuntimeMsChunks, chunks);
-}
-
 static inline u64 HvCallCfg_getSystemPhysicalProcessors(void)
 {
 	return HvCall0(HvCallCfgGetSystemPhysicalProcessors);
@@ -141,14 +102,6 @@ static inline u64 HvCallCfg_getPhysicalP
 	return HvCall2(HvCallCfgGetPhysicalProcessors, lp, qual);
 }
 
-static inline u64 HvCallCfg_getConfiguredBusUnitsForInterruptProc(HvLpIndex lp,
-		u16 hvLogicalProcIndex)
-{
-	return HvCall2(HvCallCfgGetConfiguredBusUnitsForIntProc, lp,
-			hvLogicalProcIndex);
-
-}
-
 static inline HvLpSharedPoolIndex HvCallCfg_getSharedPoolIndex(HvLpIndex lp)
 {
 	return HvCall1(HvCallCfgGetSharedPoolIndex, lp);
@@ -164,15 +117,13 @@ static inline u64 HvCallCfg_getSharedPro
 
 static inline u64 HvCallCfg_getNumProcsInSharedPool(HvLpSharedPoolIndex sPI)
 {
-	u16 retVal = HvCall1(HvCallCfgGetNumProcsInSharedPool, sPI);
-	return retVal;
+	return (u16)HvCall1(HvCallCfgGetNumProcsInSharedPool, sPI);
 
 }
 
 static inline HvLpIndex	HvCallCfg_getHostingLpIndex(HvLpIndex lp)
 {
-	u64 retVal = HvCall1(HvCallCfgGetHostingLpIndex, lp);
-	return retVal;
+	return HvCall1(HvCallCfgGetHostingLpIndex, lp);
 }
 
 #endif /* _HVCALLCFG_H */
diff -puN include/asm-ppc64/iSeries/HvLpConfig.h~ppc64-iseries-eliminate-some-unused-inline-functions include/asm-ppc64/iSeries/HvLpConfig.h
--- 25/include/asm-ppc64/iSeries/HvLpConfig.h~ppc64-iseries-eliminate-some-unused-inline-functions	2005-06-03 02:15:59.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/HvLpConfig.h	2005-06-03 02:15:59.000000000 -0700
@@ -40,127 +40,16 @@ static inline HvLpIndex	HvLpConfig_getPr
 	return itLpNaca.xPrimaryLpIndex;
 }
 
-static inline HvLpIndex	HvLpConfig_getLps(void)
-{
-	return HvCallCfg_getLps();
-}
-
-static inline HvLpIndexMap HvLpConfig_getActiveLpMap(void)
-{
-	return HvCallCfg_getActiveLpMap();
-}
-
-static inline u64 HvLpConfig_getSystemMsMegs(void)
-{
-	return HvCallCfg_getSystemMsChunks() / HVCHUNKSPERMEG;
-}
-
-static inline u64 HvLpConfig_getSystemMsChunks(void)
-{
-	return HvCallCfg_getSystemMsChunks();
-}
-
-static inline u64 HvLpConfig_getSystemMsPages(void)
-{
-	return HvCallCfg_getSystemMsChunks() * HVPAGESPERCHUNK;
-}
-
-static inline u64 HvLpConfig_getMsMegs(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Cur)
-		/ HVCHUNKSPERMEG;
-}
-
 static inline u64 HvLpConfig_getMsChunks(void)
 {
 	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Cur);
 }
 
-static inline u64 HvLpConfig_getMsPages(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Cur)
-		* HVPAGESPERCHUNK;
-}
-
-static inline u64 HvLpConfig_getMinMsMegs(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Min)
-		/ HVCHUNKSPERMEG;
-}
-
-static inline u64 HvLpConfig_getMinMsChunks(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Min);
-}
-
-static inline u64 HvLpConfig_getMinMsPages(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Min)
-		* HVPAGESPERCHUNK;
-}
-
-static inline u64 HvLpConfig_getMinRuntimeMsMegs(void)
-{
-	return HvCallCfg_getMinRuntimeMsChunks(HvLpConfig_getLpIndex())
-		/ HVCHUNKSPERMEG;
-}
-
-static inline u64 HvLpConfig_getMinRuntimeMsChunks(void)
-{
-	return HvCallCfg_getMinRuntimeMsChunks(HvLpConfig_getLpIndex());
-}
-
-static inline u64 HvLpConfig_getMinRuntimeMsPages(void)
-{
-	return HvCallCfg_getMinRuntimeMsChunks(HvLpConfig_getLpIndex())
-		* HVPAGESPERCHUNK;
-}
-
-static inline u64 HvLpConfig_getMaxMsMegs(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Max)
-		/ HVCHUNKSPERMEG;
-}
-
-static inline u64 HvLpConfig_getMaxMsChunks(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Max);
-}
-
-static inline u64 HvLpConfig_getMaxMsPages(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Max)
-		* HVPAGESPERCHUNK;
-}
-
-static inline u64 HvLpConfig_getInitMsMegs(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Init)
-		/ HVCHUNKSPERMEG;
-}
-
-static inline u64 HvLpConfig_getInitMsChunks(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Init);
-}
-
-static inline u64 HvLpConfig_getInitMsPages(void)
-{
-	return HvCallCfg_getMsChunks(HvLpConfig_getLpIndex(), HvCallCfg_Init)
-		* HVPAGESPERCHUNK;
-}
-
 static inline u64 HvLpConfig_getSystemPhysicalProcessors(void)
 {
 	return HvCallCfg_getSystemPhysicalProcessors();
 }
 
-static inline u64 HvLpConfig_getSystemLogicalProcessors(void)
-{
-	return HvCallCfg_getSystemPhysicalProcessors()
-		* (/*getPaca()->getSecondaryThreadCount() +*/ 1);
-}
-
 static inline u64 HvLpConfig_getNumProcsInSharedPool(HvLpSharedPoolIndex sPI)
 {
 	return HvCallCfg_getNumProcsInSharedPool(sPI);
@@ -172,13 +61,6 @@ static inline u64 HvLpConfig_getPhysical
 			HvCallCfg_Cur);
 }
 
-static inline u64 HvLpConfig_getLogicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Cur)
-		* (/*getPaca()->getSecondaryThreadCount() +*/ 1);
-}
-
 static inline HvLpSharedPoolIndex HvLpConfig_getSharedPoolIndex(void)
 {
 	return HvCallCfg_getSharedPoolIndex(HvLpConfig_getLpIndex());
@@ -190,57 +72,18 @@ static inline u64 HvLpConfig_getSharedPr
 			HvCallCfg_Cur);
 }
 
-static inline u64 HvLpConfig_getMinSharedProcUnits(void)
-{
-	return HvCallCfg_getSharedProcUnits(HvLpConfig_getLpIndex(),
-			HvCallCfg_Min);
-}
-
 static inline u64 HvLpConfig_getMaxSharedProcUnits(void)
 {
 	return HvCallCfg_getSharedProcUnits(HvLpConfig_getLpIndex(),
 			HvCallCfg_Max);
 }
 
-static inline u64 HvLpConfig_getMinPhysicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Min);
-}
-
-static inline u64 HvLpConfig_getMinLogicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Min)
-		* (/*getPaca()->getSecondaryThreadCount() +*/ 1);
-}
-
 static inline u64 HvLpConfig_getMaxPhysicalProcessors(void)
 {
 	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
 			HvCallCfg_Max);
 }
 
-static inline u64 HvLpConfig_getMaxLogicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Max)
-		* (/*getPaca()->getSecondaryThreadCount() +*/ 1);
-}
-
-static inline u64 HvLpConfig_getInitPhysicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Init);
-}
-
-static inline u64 HvLpConfig_getInitLogicalProcessors(void)
-{
-	return HvCallCfg_getPhysicalProcessors(HvLpConfig_getLpIndex(),
-			HvCallCfg_Init)
-		* (/*getPaca()->getSecondaryThreadCount() +*/ 1);
-}
-
 static inline HvLpVirtualLanIndexMap HvLpConfig_getVirtualLanIndexMap(void)
 {
 	return HvCallCfg_getVirtualLanIndexMap(HvLpConfig_getLpIndex_outline());
@@ -252,37 +95,6 @@ static inline HvLpVirtualLanIndexMap HvL
 	return HvCallCfg_getVirtualLanIndexMap(lp);
 }
 
-static inline HvLpIndex HvLpConfig_getBusOwner(HvBusNumber busNumber)
-{
-	return HvCallCfg_getBusOwner(busNumber);
-}
-
-static inline int HvLpConfig_isBusDedicated(HvBusNumber busNumber)
-{
-	return HvCallCfg_isBusDedicated(busNumber);
-}
-
-static inline HvLpIndexMap HvLpConfig_getBusAllocation(HvBusNumber busNumber)
-{
-	return HvCallCfg_getBusAllocation(busNumber);
-}
-
-/* returns the absolute real address of the load area */
-static inline u64 HvLpConfig_getLoadAddress(void)
-{
-	return itLpNaca.xLoadAreaAddr & 0x7fffffffffffffff;
-}
-
-static inline u64 HvLpConfig_getLoadPages(void)
-{
-	return itLpNaca.xLoadAreaChunks * HVPAGESPERCHUNK;
-}
-
-static inline int HvLpConfig_isBusOwnedByThisLp(HvBusNumber busNumber)
-{
-	return (HvLpConfig_getBusOwner(busNumber) == HvLpConfig_getLpIndex());
-}
-
 static inline int HvLpConfig_doLpsCommunicateOnVirtualLan(HvLpIndex lp1,
 		HvLpIndex lp2)
 {
_
